@@ -80,10 +80,10 @@ ngram <- function(phrases, corpus='eng_2012', year_start = 1500,
                                                     tag=tag))
   result <- do.call("rbind", dfs)
   result$Corpus <- as.factor(result$Corpus)
-  if (count) result <- add_count(result)
   class(result) <- c("ngram", class(result))
   attr(result, "smoothing") <- smoothing
   attr(result, "case_sensitive") <- TRUE
+  if (count) result <- add_count(result)
   return(result)
 }
 
@@ -111,20 +111,28 @@ ngram_fetch <- function(phrases, corpus, year_start,  year_end, smoothing) {
   phrases <- phrases[phrases != ""]
   if (length(phrases)==0) stop("No valid phrases provided.")
   ng_url <- ngram_url(phrases, query)
-  conn <- url(ng_url)
-  html <- readLines(conn)
-  close(conn)
+  html <- strsplit(getURL(ng_url, ssl.verifypeer = FALSE), "\n", perl=TRUE)[[1]]
   result <- ngram_parse(html)
   result <- reshape2::melt(result, id.vars="Year", variable.name="Phrase", value.name="Frequency")
   return(result)
 }
 
 ngram_url <- function(phrases, query=character()){
-  url <- 'http://books.google.com/ngrams/graph'
-  phrases <- paste(curlEscape(str_trim(phrases)), collapse='%2C')
+  url <- 'https://books.google.com/ngrams/interactive_chart'
+  n <- length(phrases)
+  direct_url <- paste(rep("t1", n), phrases, rep("c0", n), sep=";,", collapse=";.")
+  direct_url <- gsub(",", "%2c", URLencode(direct_url, reserved=TRUE), fixed=TRUE)
+  direct_url <- gsub("%28", "(", direct_url)
+  direct_url <- gsub("%29", ")", direct_url)
+  direct_url <- gsub("+", "%2b", direct_url, fixed=TRUE)
+  phrases <- paste(curlEscape(str_trim(phrases)), collapse='%2c')
   if (phrases=="") stop("No valid phrases provided.")
   url <- paste0(url, "?content=", phrases) 
   if (length(query) > 0) url <- modify_url(url, query=query)
+  url <- gsub("%28", "(", url)
+  url <- gsub("%29", ")", url)
+  url <- gsub("%20", "+", url)
+  url <- paste0(url, "&direct_url=", direct_url) 
   return(url)
 }
 
@@ -135,18 +143,14 @@ ngram_parse <- function(html){
   lapply(grep("^Google has substituted ",
               gsub("<.?b.?>","", sub("Replaced (.*) to match how we processed the books",
                                               "Google has substituted \\1", html)),
-              value=TRUE), warning, call. = FALSE)
-    
-  cols <- lapply(strsplit(grep("addColumn", html, value=TRUE), ","), getElement, 2)
-  
-  cols <- gsub(".*'(.*)'.*", "\\1", cols)
-  cols <- as.character(parse(text=paste0("'", cols, "'")))
-
-  html <- paste(html[-(1:grep("data.addRows\\(", html))], collapse='')
-  html <- gsub("\\).*", "", html)
-  
-  data <- as.data.frame(t(sapply(fromJSON(html), unlist)))
-  colnames(data) <- cols
+              value=TRUE), warning, call. = FALSE)  
+  data_line <- grep("var data", html)
+  ngram_data <- fromJSON(sub(".*=", "", html[data_line]))
+  years <- as.integer(strsplit(html[data_line + 1], ",")[[1]][2:3])
+  cols <- unlist(lapply(ngram_data, function(x) x$ngram))
+  data <- as.data.frame(lapply(ngram_data, function(x) x$timeseries))
+  data <- cbind(seq.int(years[1], years[2]), data)
+  colnames(data) <- c("Year", cols)
   return(data)
 }
 
